@@ -1,5 +1,5 @@
 import keyring
-from easyrsa import EasyRSA
+from easyrsa import *
 from omnitools import *
 from aescipher import *
 
